<?
$text = "1234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890\n";
$loop = 10000;

/**
 * No need for flock, since this methods uses a+. fwrite is atomic here.
 * see: http://us3.php.net/manual/en/function.fwrite.php
 */
function notClosing() {
	global $text, $loop;
	$file = 'test1.log';
	if(file_exists($file)) {
	    unlink($file);
	}
	$fp = fopen($file, 'a+');
	
	$count = 0;
	$time_start = microtime(true);
	while($count < $loop) {
		fwrite($fp, $text);
		$count++; 
	}
	$time_end = microtime(true);
	$time = $time_end - $time_start;
	
	echo "Execution with NOT closing the log file took $time seconds\n";
	fclose($fp);
}

function closing() {
	global $text, $loop;
	$file = 'test2.log';
	if(file_exists($file)) {
	    unlink($file);
	}
	
	$count = 0;
	$time_start = microtime(true);
	while($count < $loop) {
		$fp = fopen($file, 'a+');
		fwrite($fp, $text);
		fclose($fp);
		$count++; 
	}
	$time_end = microtime(true);
	$time = $time_end - $time_start;
	
	echo "Execution with CLOSING the log after each write file took $time seconds\n";
	
}

function putContent() {
	global $text, $loop;
	$file = 'test3.log';
	if(file_exists($file)) {
	    unlink($file);
	}
	
	$count = 0;
	$time_start = microtime(true);
	while($count < $loop) {
		file_put_contents($file, $text, FILE_APPEND);
		$count++; 
	}
	$time_end = microtime(true);
	$time = $time_end - $time_start;
	
	echo "Execution with file_put_content took $time seconds\n";
}

/**
 * Needs flock to aquire a lock to the file
 */
function lock() {
    global $text, $loop;
	$file = 'test4.log';
	if(file_exists($file)) {
	   unlink($file);
	}
	$fp = fopen($file, 'a+');
	stream_set_blocking($fp, 0);
	
	$count = 0;
	$time_start = microtime(true);
	flock($fp, LOCK_UN);
	while($count < $loop) {
		if (flock($fp, LOCK_EX)) {
			fwrite($fp, $text);
		}
		flock($fp, LOCK_UN);
		$count++; 
	}
	
	$time_end = microtime(true);
	$time = $time_end - $time_start;
	
	fclose($fp);
	echo "Execution with leaving the file open, but LOCKING and UNLOCKING it took $time seconds\n";
	
}


/**
 * Needs flock to aquire a lock to the file
 */
function stream() {
    global $text, $loop;
	$file = 'test5.log';
	if(file_exists($file)) {
	    unlink($file);
	}
	$fp = fopen($file, 'a+');
	stream_set_blocking($fp, 0);
	
	$count = 0;
	$time_start = microtime(true);
	while($count < $loop) {
		if (flock($fp, LOCK_EX)) {
			fwrite($fp, $text);
		}
		flock($fp, LOCK_UN);
		$count++; 
	}
	
	$time_end = microtime(true);
	$time = $time_end - $time_start;
	
	fclose($fp);
	echo "Execution with nonblocking stream took $time seconds\n";
}

function errorLog() {
    global $text, $loop;
	$file = 'test6.log';
	if(file_exists($file)) {
	    unlink($file);
	}
	
	$count = 0;
	$time_start = microtime(true);
	while($count < $loop) {
		error_log($text, 3, $file);
		$count++; 
	}
	
	$time_end = microtime(true);
	$time = $time_end - $time_start;
	
	echo "Execution with the error_log method took $time seconds\n";
	
}

notClosing();
closing();
putContent();
lock();
stream();
errorLog();
/*
 * Output on MacOSX Tiger Intel Core Duo
 
Execution with NOT closing the log file took 0.0668561458588 seconds
Execution with CLOSING the log after each write file took 30.1630220413 seconds
Execution with file_put_content took 30.153963089 seconds
Execution with leaving the file open, but LOCKING and UNLOCKING it took 0.148998975754 seconds
Execution with nonblocking stream took 0.149605989456 seconds
Execution with the error_log method took 30.069578886 seconds
*/